pub struct PayInMethod {
pub id: i32,
pub code: String,
pub requires_credit_card: bool,
pub event_tracking_code: Option<String>,
pub icon: Option<String>,
pub enabled: bool,
pub translated_name: Option<String>,
pub note: Option<String>,
pub method_change_possible: bool,
}Fields
id: i32code: StringCode of the payment method given by Vinted
requires_credit_card: boolIf the payment method requires a credit card
event_tracking_code: Option<String>icon: Option<String>Icon of the payment method
enabled: booltranslated_name: Option<String>note: Option<String>method_change_possible: boolTrait Implementations
Sourceimpl Clone for PayInMethod
impl Clone for PayInMethod
Sourcefn clone(&self) -> PayInMethod
fn clone(&self) -> PayInMethod
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PayInMethod
impl Debug for PayInMethod
Sourceimpl<'de> Deserialize<'de> for PayInMethod
impl<'de> Deserialize<'de> for PayInMethod
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for PayInMethod
impl Display for PayInMethod
impl Eq for PayInMethod
Sourceimpl FromRedisValue for PayInMethod
impl FromRedisValue for PayInMethod
Sourcefn from_redis_value(v: &Value) -> RedisResult<Self>
fn from_redis_value(v: &Value) -> RedisResult<Self>
Given a redis
Value this attempts to convert it into the given
destination type. If that fails because it’s not compatible an
appropriate error is generated.Sourcefn from_owned_redis_value(v: Value) -> Result<Self, RedisError>
fn from_owned_redis_value(v: Value) -> Result<Self, RedisError>
Given a redis
Value this attempts to convert it into the given
destination type. If that fails because it’s not compatible an
appropriate error is generated.Sourcefn from_redis_values(items: &[Value]) -> Result<Vec<Self>, RedisError>
fn from_redis_values(items: &[Value]) -> Result<Vec<Self>, RedisError>
Similar to
from_redis_value but constructs a vector of objects
from another vector of values. This primarily exists internally
to customize the behavior for vectors of tuples.Sourcefn from_owned_redis_values(items: Vec<Value>) -> Result<Vec<Self>, RedisError>
fn from_owned_redis_values(items: Vec<Value>) -> Result<Vec<Self>, RedisError>
The same as
from_redis_values, but takes a Vec<Value> instead
of a &[Value].Sourcefn from_owned_byte_vec(_vec: Vec<u8>) -> Result<Vec<Self>, RedisError>
fn from_owned_byte_vec(_vec: Vec<u8>) -> Result<Vec<Self>, RedisError>
Convert bytes to a single element vector.
Sourceimpl Hash for PayInMethod
impl Hash for PayInMethod
Sourceimpl PartialEq for PayInMethod
impl PartialEq for PayInMethod
Sourceimpl Serialize for PayInMethod
impl Serialize for PayInMethod
impl StructuralPartialEq for PayInMethod
Sourceimpl ToRedisArgs for PayInMethod
impl ToRedisArgs for PayInMethod
Sourcefn write_redis_args<W>(&self, out: &mut W)where
W: ?Sized + RedisWrite,
fn write_redis_args<W>(&self, out: &mut W)where
W: ?Sized + RedisWrite,
This writes the value into a vector of bytes. Each item
is a single argument. Most items generate a single item. Read more
Sourcefn to_redis_args(&self) -> Vec<Vec<u8>>
fn to_redis_args(&self) -> Vec<Vec<u8>>
This converts the value into a vector of bytes. Each item
is a single argument. Most items generate a vector of a
single item. Read more
Sourcefn describe_numeric_behavior(&self) -> NumericBehavior
fn describe_numeric_behavior(&self) -> NumericBehavior
Returns an information about the contained value with regards
to it’s numeric behavior in a redis context. This is used in
some high level concepts to switch between different implementations
of redis functions (for instance
INCR vs INCRBYFLOAT).Sourcefn num_of_args(&self) -> usize
fn num_of_args(&self) -> usize
Returns the number of arguments this value will generate. Read more